-- RX_BITSLICE: RX_BITSLICE for input using Native Mode
--              UltraScale
-- Xilinx HDL Language Template, version 2022.2

RX_BITSLICE_inst : RX_BITSLICE
generic map (
   CASCADE => "FALSE",             -- Enables cascading of IDELAY and ODELAY lines
   DATA_TYPE => "DATA",            -- Defines what the input pin is carrying (CLOCK, DATA, DATA_AND_CLOCK,
                                   -- SERIAL)
   DATA_WIDTH => 8,                -- Defines the width of the serial-to-parallel converter (4-8)
   DELAY_FORMAT => "TIME",         -- Units of the DELAY_VALUE (COUNT, TIME)
   DELAY_TYPE => "FIXED",          -- Set the type of tap delay line (FIXED, VARIABLE, VAR_LOAD)
   DELAY_VALUE => 0,               -- Input delay value setting in ps
   DELAY_VALUE_EXT => 0,           -- Value of the extended input delay value in ps
   FIFO_SYNC_MODE => "FALSE",      -- Always set to FALSE. TRUE is reserved for later use.
   IS_CLK_EXT_INVERTED => '0',     -- Optional inversion for CLK_EXT
   IS_CLK_INVERTED => '0',         -- Optional inversion for CLK
   IS_RST_DLY_EXT_INVERTED => '0', -- Optional inversion for RST_DLY_EXT
   IS_RST_DLY_INVERTED => '0',     -- Optional inversion for RST_DLY
   IS_RST_INVERTED => '0',         -- Optional inversion for RST
   REFCLK_FREQUENCY => 300.0,      -- Specification of the reference clock frequency in MHz (200.0-2667.0)
   SIM_DEVICE => "ULTRASCALE",     -- Set the device version for simulation functionality (ULTRASCALE)
   UPDATE_MODE => "ASYNC",         -- Determines when updates to the delay will take effect (ASYNC, MANUAL,
                                   -- SYNC)
   UPDATE_MODE_EXT => "ASYNC"      -- Determines when updates to the extended input delay will take effect
                                   -- (ASYNC, MANUAL, SYNC)
)
port map (
   CNTVALUEOUT => CNTVALUEOUT,         -- 9-bit output: Counter value to device logic
   CNTVALUEOUT_EXT => CNTVALUEOUT_EXT, -- 9-bit output: Optional extended (cascaded delay) counter value
                                       -- going to the device logic

   FIFO_EMPTY => FIFO_EMPTY,           -- 1-bit output: FIFO empty flag
   FIFO_WRCLK_OUT => FIFO_WRCLK_OUT,   -- 1-bit output: FIFO source synchronous write clock out to the
                                       -- device logic (currently unsupported, do not connect)

   Q => Q,                             -- 8-bit output: Registered output data from FIFO
   RX_BIT_CTRL_OUT => RX_BIT_CTRL_OUT, -- 40-bit output: Output bus to BITSLICE_CONTROL
   TX_BIT_CTRL_OUT => TX_BIT_CTRL_OUT, -- 40-bit output: Output bus to BITSLICE_CONTROL
   CE => CE,                           -- 1-bit input: Clock enable for IDELAY
   CE_EXT => CE_EXT,                   -- 1-bit input: Optional extended (cascaded delay) clock enable
   CLK => CLK,                         -- 1-bit input: Clock used to sample LOAD, CE, INC
   CLK_EXT => CLK_EXT,                 -- 1-bit input: Optional extended (cascaded delay) clock
   CNTVALUEIN => CNTVALUEIN,           -- 9-bit input: Counter value from device logic
   CNTVALUEIN_EXT => CNTVALUEIN_EXT,   -- 9-bit input: Optional extended (cascaded delay) counter value from
                                       -- device logic

   DATAIN => DATAIN,                   -- 1-bit input: Input signal from IBUF
   EN_VTC => EN_VTC,                   -- 1-bit input: Enable IDELAYCTRL to keep stable delay over VT
   EN_VTC_EXT => EN_VTC_EXT,           -- 1-bit input: Optional extended (cascaded delay) to keep stable
                                       -- delay over VT

   FIFO_RD_CLK => FIFO_RD_CLK,         -- 1-bit input: FIFO read clock
   FIFO_RD_EN => FIFO_RD_EN,           -- 1-bit input: FIFO read enable
   INC => INC,                         -- 1-bit input: Increment the current delay tap setting
   INC_EXT => INC_EXT,                 -- 1-bit input: Optional extended (cascaded delay) increments the
                                       -- current delay tap setting

   LOAD => LOAD,                       -- 1-bit input: Load the CNTVALUEIN tap setting
   LOAD_EXT => LOAD_EXT,               -- 1-bit input: Optional extended (cascaded delay) load the
                                       -- CNTVALUEIN_EXT tap setting

   RST => RST,                         -- 1-bit input: Asynchronous assert, synchronous deassert for
                                       -- RX_BITSLICE ISERDES

   RST_DLY => RST_DLY,                 -- 1-bit input: Reset the internal DELAY value to DELAY_VALUE
   RST_DLY_EXT => RST_DLY_EXT,         -- 1-bit input: Optional extended (cascaded delay) reset delay to
                                       -- DELAY_VALUE_EXT

   RX_BIT_CTRL_IN => RX_BIT_CTRL_IN,   -- 40-bit input: Input bus from BITSLICE_CONTROL
   TX_BIT_CTRL_IN => TX_BIT_CTRL_IN    -- 40-bit input: Input bus from BITSLICE_CONTROL
);

-- End of RX_BITSLICE_inst instantiation
